@@ -1,4 +1,4 @@
-.onLoad <- function(lib, pkg) {
+.onAttach <- function(lib, pkg) {
 #	library.dynam("spgwr", pkg, lib)
 	packageStartupMessage(paste(
             "NOTE: This package does not constitute approval of GWR",
